/v1/projects/{project_id}/qemu/vms — GNS3 1.3.dev1 documentation

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »
- Qemu »

# /v1/projects/{project_id}/qemu/vms

Contents

- /v1/projects/{project_id}/qemu/vms
  - POST /v1/projects/{project_id}/qemu/vms
    - Parameters
    - Response status codes
    - Input
    - Output

## POST /v1/projects/{project_id}/qemu/vms

Create a new Qemu.instance

### Parameters

- project_id: UUID for the project

### Response status codes

- 400: Invalid request
- 201: Instance created
- 409: Conflict

### Input

Name | Mandatory | Type | Description
--- | --- | --- | ---
adapter_type |  | ['string', 'null'] | QEMU adapter type
adapters |  | ['integer', 'null'] | number of adapters
console |  | ['integer', 'null'] | console TCP port
cpu_throttling |  | ['integer', 'null'] | Percentage of CPU allowed for QEMU
hda_disk_image |  | ['string', 'null'] | QEMU hda disk image path
hdb_disk_image |  | ['string', 'null'] | QEMU hdb disk image path
initrd |  | ['string', 'null'] | QEMU initrd path
kernel_command_line |  | ['string', 'null'] | QEMU kernel command line
kernel_image |  | ['string', 'null'] | QEMU kernel image path
legacy_networking |  | ['boolean', 'null'] | Use QEMU legagy networking commands (-net syntax)
monitor |  | ['integer', 'null'] | monitor TCP port
name | ✔ | string | QEMU VM instance name
options |  | ['string', 'null'] | Additional QEMU options
process_priority |  | enum | Possible values: realtime, very high, high, normal, low, very low, null
qemu_path | ✔ | string | Path to QEMU
ram |  | ['integer', 'null'] | amount of RAM in MB
vm_id |  | ['string', 'null'] | QEMU VM UUID

### Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
adapter_type | ✔ | string | QEMU adapter type
adapters | ✔ | integer | number of adapters
console | ✔ | integer | console TCP port
cpu_throttling | ✔ | integer | Percentage of CPU allowed for QEMU
hda_disk_image | ✔ | string | QEMU hda disk image path
hdb_disk_image | ✔ | string | QEMU hdb disk image path
initrd | ✔ | string | QEMU initrd path
kernel_command_line | ✔ | string | QEMU kernel command line
kernel_image | ✔ | string | QEMU kernel image path
legacy_networking | ✔ | boolean | Use QEMU legagy networking commands (-net syntax)
monitor | ✔ | integer | monitor TCP port
name | ✔ | string | QEMU VM instance name
options | ✔ | string | Additional QEMU options
process_priority | ✔ | enum | Possible values: realtime, very high, high, normal, low, very low
project_id | ✔ | string | Project uuid
qemu_path | ✔ | string | path to QEMU
ram | ✔ | integer | amount of RAM in MB
vm_id | ✔ | string | QEMU VM uuid

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »
- Qemu »